<?php

class WPLinkedInAdmin {

	function __construct($plugin) {
		$this->plugin = $plugin;
		$this->linkedin = wp_linkedin_connection();
		$this->add_settings();
		add_action('admin_notices', array(&$this, 'admin_notices'));
		add_action('admin_enqueue_scripts', array(&$this, 'enqueue_scripts'));
	}

	function enqueue_scripts($hook) {
		if ($hook == $this->option_page_hook) {
			wp_enqueue_style('wp-linkedin-admin', plugins_url('theme/style.css', __FILE__), false, '1.0');
		}
	}

	function add_settings() {
		add_filter('plugin_action_links_' . WP_LINKEDIN_PLUGIN_BASENAME, array(&$this, 'add_settings_link'));
		$this->option_page_hook = add_submenu_page('options-general.php', __('LinkedIn Options', 'wp-linkedin'), __('LinkedIn', 'wp-linkedin'), 'manage_options', 'wp-linkedin', array(&$this, 'options_page'));

		add_settings_section('default', __('Options', 'wp-linkedin'), false, 'wp-linkedin');
		$this->add_options_field('wp-linkedin_full_profile', __('Full Profile', 'wp-linkedin'), 'add_settings_field_full_profile');
		$this->add_options_field('wp-linkedin_fields', __('Profile fields', 'wp-linkedin'), 'add_settings_field_fields');
		$this->add_options_field('wp-linkedin_profilelanguage', __('Profile language', 'wp-linkedin'), 'add_settings_field_profilelanguage');
		$this->add_options_field('wp-linkedin_sendmail_on_token_expiry', __('Send mail on token expiry', 'wp-linkedin'), 'add_settings_field_sendmail_on_token_expiry');
		$this->add_options_field('wp-linkedin_ssl_verifypeer', __('Verify SSL peer', 'wp-linkedin'), 'add_settings_field_ssl_verifypeer');
		$this->add_options_field('wp-linkedin_add_card_to_content', __('LinkedIn cards', 'wp-linkedin'), 'add_settings_field_add_card_to_content');

		add_settings_section('apikeys', __('LinkedIn API', 'wp-linkedin'), array(&$this, 'api_access_section'), 'wp-linkedin');
		$this->add_options_field('wp-linkedin_appkey', __('Client ID', 'wp-linkedin'), 'add_settings_field_appkey', 'apikeys');
		$this->add_options_field('wp-linkedin_appsecret', __('Client secret', 'wp-linkedin'), 'add_settings_field_appsecret', 'apikeys');

		add_settings_section('extensions', __('Extensions', 'wp-linkedin'), array(&$this, 'extensions_section'), 'wp-linkedin');
	}

	function add_options_field($id, $title, $callback, $section = 'default') {
		register_setting('wp-linkedin', $id);
		add_settings_field($id, $title, array(&$this, $callback), 'wp-linkedin', $section);
	}

	function add_settings_link($links) {
		$url = site_url('/wp-admin/options-general.php?page=wp-linkedin');
		$links[] = '<a href="' . $url . '">' . __('Settings') . '</a>';
		return $links;
	}

	function api_access_section() {
		$redirect_uri = $this->linkedin->get_token_process_url(); ?>
		<p><?php _e('As of April 11, 2014 LinkedIn requires that redirect uris
				be registered, thus forcing every plugin installation to have
				its own application key/secret pair and register the corresponding
				redirect uri.', 'wp-linkedin'); ?></p>
		<p><?php _e('Please follow the instructions on <a href="http://vdvn.me/p2tt" target="_blank">how to create a LinkedIn API application for the WP-LinkedIn plugin</a>.', 'wp-linkedin'); ?></p>
		<table class="form-table">
			<tr>
				<th scope="row"><?php _e('Redirect URL', 'wp-linkedin'); ?></th>
				<td><input type="text" class="regular-text" readonly value="<?php echo $redirect_uri; ?>"</td>
			</tr>
		</table><?php
	}

	function download_link($pid) {
		echo "http://vdvn.me/checkout?download_id={$pid}&edd_action=add_to_cart";
	}

	function extensions_section() { ?>
		<p><?php _e('Extensions are premium WordPress plugins that add new features to the WP-LinkedIn plugin.', 'wp-linkedin'); ?>
		<?php _e('The following is a list of the existing extensions.', 'wp-linkedin'); ?></p>
		<div class="extension"><div class="extension-inner">
			<strong><a href="http://vdvn.me/p1nd"><?php _e('WP LinkedIn Multi-Users', 'wp-linkedin'); ?></a></strong>
			<p><?php _e('Enables profiles and recommendations for any registered user. Enables users to create accounts and log in using LinkedIn', 'wp-linkedin'); ?></p>
			<span class="submit"><a class="button button-primary" href="<?php $this->download_link(2137); ?>"><?php _e('Get it!', 'wp-linkedin'); ?></a></span>
		</div></div>
		<div class="extension"><div class="extension-inner">
			<strong><a href="http://vdvn.me/p1nr"><?php _e('WP LinkedIn for Companies', 'wp-linkedin'); ?></a></strong>
			<p><?php _e('Provides shortcodes and widgets to display company profiles and company page updates on your blog.', 'wp-linkedin'); ?></p>
			<span class="submit"><a class="button button-primary" href="<?php $this->download_link(2151); ?>"><?php _e('Get it!', 'wp-linkedin'); ?></a></span>
		</div></div>
		<div class="extension"><div class="extension-inner">
			<strong><a href="http://vdvn.me/p2ub"><?php _e('WP LinkedIn Advanced Templates', 'wp-linkedin'); ?></a></strong>
			<p><?php _e('Provides advanced templates for the LinkedIn profile and the company page updates.', 'wp-linkedin'); ?></p>
			<span class="submit"><a class="button button-primary" href="<?php $this->download_link(3683); ?>"><?php _e('Get it!', 'wp-linkedin'); ?></a></span>
		</div></div>
		<p style="clear:both"><?php _e('If you purchased any extension please provide the license keys below.', 'wp-linkedin'); ?></p><?php
	}

	function add_settings_field_appkey() { ?>
		<input type="text" name="wp-linkedin_appkey" class="regular-text" value="<?php echo WP_LINKEDIN_APPKEY; ?>" /><?php
	}

	function add_settings_field_appsecret() { ?>
		<input type="text" name="wp-linkedin_appsecret" class="regular-text" value="<?php echo WP_LINKEDIN_APPSECRET; ?>" /><?php
	}

	function add_settings_field_full_profile() { ?>
		<label><input type="checkbox" name="wp-linkedin_full_profile"
			value="1" <?php checked(LINKEDIN_FULL_PROFILE); ?> />&nbsp;
			<?php _e('Check this option only if you have been authorized by LinkedIn to access the full profile.', 'wp-linkedin') ?></label>
		<p><em><?php _e('To be authorized you must apply to <a target="_blank" href="https://help.linkedin.com/app/ask/path/api-dvr">the "Apply with LinkedIn" program</a>.',
				'wp-linkedin'); ?>
			<?php _e('<a href="http://vdvn.me/p2lg" target="_blank">More information on vedovini.net</a>',
				'wp-linkedin'); ?></em></p><?php
	}

	function add_settings_field_fields() { ?>
		<textarea id="wp-linkedin_fields" name="wp-linkedin_fields" rows="5"
		class="large-text"><?php echo get_option('wp-linkedin_fields', LINKEDIN_FIELDS_DEFAULT); ?></textarea>
		<p><em><?php _e('Comma separated list of fields to show on the profile.', 'wp-linkedin'); ?>
		<?php _e('You can overide this setting in the shortcode with the `fields` attribute.', 'wp-linkedin'); ?>
		<?php _e('See the <a href="https://developers.linkedin.com/documents/profile-fields" target="_blank">LinkedIn API documentation</a> for the complete list of fields.', 'wp-linkedin'); ?></em></p><?php
	}

	function add_settings_field_profilelanguage() { ?>
		<select id="wp-linkedin_profilelanguage" name="wp-linkedin_profilelanguage"><?php
			$lang = get_option('wp-linkedin_profilelanguage');
			$languages = $this->getLanguages();

			echo '<option value="" ' . selected($lang, '', false) . '>' . __('Default', 'wp-linkedin') . '</option>';

			foreach ($languages as $k => $v) {
				echo '<option value="' . $k . '" ' . selected($lang, $k, false) . '>' . $v . '</option>';
			} ?>
		</select>
		<p><em><?php _e('The language of the profile to display if you have several profiles in different languages.', 'wp-linkedin'); ?>
		<?php _e('You can overide this setting in the shortcode with the `lang` attribute.', 'wp-linkedin'); ?>
		<?php _e('See "Selecting the profile language" <a href="https://developer.linkedin.com/documents/profile-api" target="_blank">LinkedIn API documentation</a> for details.', 'wp-linkedin'); ?></em></p><?php
	}

	function add_settings_field_sendmail_on_token_expiry() { ?>
		<label><input type="checkbox" name="wp-linkedin_sendmail_on_token_expiry"
			value="1" <?php checked(LINKEDIN_SENDMAIL_ON_TOKEN_EXPIRY); ?> />&nbsp;
			<?php _e('Check this option if you want the plugin to send you an email when the token has expired or is invalid.', 'wp-linkedin') ?></label><?php
	}

	function add_settings_field_ssl_verifypeer() { ?>
		<label><input type="checkbox" name="wp-linkedin_ssl_verifypeer"
			value="1" <?php checked(LINKEDIN_SSL_VERIFYPEER); ?> />&nbsp;
			<?php _e('Uncheck this option only if you have SSL certificate issues on your server.', 'wp-linkedin') ?></label><?php
	}

	function add_settings_field_add_card_to_content() {
		$post_types = $this->plugin->get_post_types();
		$wp_post_types = get_post_types(array('public' => true), 'objects'); ?>
		<p><?php foreach ($wp_post_types as $name => $post_type): ?>
		<label style="white-space:nowrap;"><input type="checkbox" name="wp-linkedin_add_card_to_content[]"
			value="<?php echo $name; ?>" <?php checked(in_array($name, $post_types)); ?> /><?php echo $post_type->labels->name; ?></label>&nbsp;
		<?php endforeach; ?></p>
		<p><em><?php _e('Check the content types where you want your LinkedIn card inserted.', 'wp-linkedin') ?></em></p><?php
	}

	function admin_notices() {
		if (!WP_LINKEDIN_APPKEY && (current_user_can('manage_options'))) {
			$format = __('Your must create an application key/secret to access the LinkedIn API. Please follow the instructions <a href="%s">on the settings page</a>.', 'wp-linkedin');
			$notice = sprintf($format, site_url('/wp-admin/options-general.php?page=wp-linkedin#apikeys')); ?>
			<div class="error"><p><?php echo $notice; ?></p></div><?php
			return;
		}

		if (!$this->linkedin->is_access_token_valid()) {
			$format = __('Your LinkedIn access token is invalid or has expired, please <a href="%s">click here</a> to get a new one.', 'wp-linkedin');
			$notice = sprintf($format, $this->linkedin->get_authorization_url()); ?>
			<div class="error"><p><?php echo $notice; ?></p></div><?php
		}

		if (LI_DEBUG && $this->linkedin->get_last_error()) { ?>
			<div class="error">
		        <p><?php _e('An error has occured while retrieving the profile:', 'wp-linkedin'); ?> <?php echo $this->linkedin->get_last_error(); ?></p>
			</div><?php
		}

		if (isset($_GET['oauth_status'])) {
			switch ($_GET['oauth_status']) {
				case 'success':
					$message = isset($_GET['oauth_message']) ? $_GET['oauth_message'] : __('The access token has been successfully updated.', 'wp-linkedin'); ?>
					<div class="updated"><p><?php echo $message; ?></p></div><?php
					break;

				case 'error':
					$message = isset($_GET['oauth_message']) ? $_GET['oauth_message'] : false; ?>
					<div class="error">
					<p><?php _e('An error has occured while updating the access token, please try again.', 'wp-linkedin'); ?>
					<?php echo ($message) ? '<br/>' . __('Error message: ', 'wp-linkedin') . $message : ''; ?></p>
					</div><?php
					break;
			}
		}

		if (isset($_GET['cache_cleared'])) { ?>
			<div class="updated"><p><?php _e('The cache has been cleared.', 'wp-linkedin'); ?></p></div><?php
		}
	}

	function options_page() {
		if (isset($_GET['clear_cache'])) {
			$this->linkedin->clear_cache(); ?>
			<div class="updated"><p><strong><?php _e('The cache has been cleared.', 'wp-linkedin'); ?></strong></p></div><?php
		}

		include 'page-options.php';
	}

	function getLanguages() {
		static $languages;

		if (!isset($languages)) {
			$languages = array(
				'in-ID' => __('Bahasa Indonesia', 'wp-linkedin'),
				'cs-CZ' => __('Czech', 'wp-linkedin'),
				'da-DK' => __('Danish', 'wp-linkedin'),
				'nl-NL' => __('Dutch', 'wp-linkedin'),
				'fr-FR' => __('French', 'wp-linkedin'),
				'de-DE' => __('German', 'wp-linkedin'),
				'it-IT' => __('Italian', 'wp-linkedin'),
				'ja-JP' => __('Japanese', 'wp-linkedin'),
				'ko-KR' => __('Korean', 'wp-linkedin'),
				'ms-MY' => __('Malay', 'wp-linkedin'),
				'no-NO' => __('Norwegian', 'wp-linkedin'),
				'pl-PL' => __('Polish', 'wp-linkedin'),
				'pt-BR' => __('Portuguese', 'wp-linkedin'),
				'ro-RO' => __('Romanian', 'wp-linkedin'),
				'ru-RU' => __('Russian', 'wp-linkedin'),
				'es-ES' => __('Spanish', 'wp-linkedin'),
				'sv-SE' => __('Swedish', 'wp-linkedin'),
				'tr-TR' => __('Turkish', 'wp-linkedin'),
				'sq-AL' => __('Albanian', 'wp-linkedin'),
				'hy-AM' => __('Armenian', 'wp-linkedin'),
				'bs-BA' => __('Bosnian', 'wp-linkedin'),
				'my-MM' => __('Burmese (Myanmar)', 'wp-linkedin'),
				'zh-CN' => __('Chinese (Simplified)', 'wp-linkedin'),
				'zh-TW' => __('Chinese (Traditional)', 'wp-linkedin'),
				'hr-HR' => __('Croatian', 'wp-linkedin'),
				'fi-FI' => __('Finnish', 'wp-linkedin'),
				'el-GR' => __('Greek', 'wp-linkedin'),
				'hi-IN' => __('Hindi', 'wp-linkedin'),
				'hu-HU' => __('Hungarian', 'wp-linkedin'),
				'is-IS' => __('Icelandic', 'wp-linkedin'),
				'jv-JV' => __('Javanese', 'wp-linkedin'),
				'kn-IN' => __('Kannada', 'wp-linkedin'),
				'lv-LV' => __('Latvian', 'wp-linkedin'),
				'lt-LT' => __('Lithuanian', 'wp-linkedin'),
				'ml-IN' => __('Malayalam', 'wp-linkedin'),
				'sr-BA' => __('Serbian', 'wp-linkedin'),
				'sk-SK' => __('Slovak', 'wp-linkedin'),
				'tl-PH' => __('Tagalog', 'wp-linkedin'),
				'ta-IN' => __('Tamil', 'wp-linkedin'),
				'te-IN' => __('Telugu', 'wp-linkedin'),
				'th-TH' => __('Thai', 'wp-linkedin'),
				'uk-UA' => __('Ukrainian', 'wp-linkedin'),
				'vi-VN' => __('Vietnamese', 'wp-linkedin'),
				'xx-XX' => __('Other', 'wp-linkedin')
			);
			asort($languages);
		}

		return $languages;
	}
}